window.Gleam.initSearch([{"doc":"okay","title":"okay","content":"# okay\n\n[![Package Version](https://img.shields.io/hexpm/v/okay)](https://hex.pm/packages/okay)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/okay/)\n\n```sh\ngleam add okay@1\n```\n```gleam\nimport okay\n\npub type User {\n  User(id: Int, name: String, age: Int)\n}\n\npub fn main() {\n  let user = User(id: 1, name: &quot;John&quot;, age: 20)\n\n  let assert Ok(_) = okay.new()\n  |&gt; okay.field(&quot;age&quot;, okay.is_gt(user.age, 18))\n  |&gt; okay.field(&quot;name&quot;, okay.is_longer(user.name, 1))\n  |&gt; okay.run()\n\n  let assert Error(validator) =\n    okay.new()\n    |&gt; okay.field(&quot;age&quot;, okay.is_gt(user.age, 30))\n    |&gt; okay.field(&quot;name&quot;, okay.is_longer(user.name, 5))\n    |&gt; okay.run()\n\n  let assert [first, second] = validator.errors\n  io.debug(first) // ValidationError(&quot;age&quot;, IsGreater(value: 20, expected: 30))\n  io.debug(second) // ValidationError(&quot;name&quot;, IsLonger(value: &quot;John&quot;, actual: 4, expected: 5))\n}\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/okay&gt;.\n\n## Development\n\n```sh\ngleam run   # Run the project\ngleam test  # Run the tests\n```\n","url":"index.html"},{"doc":"okay","title":"Error","content":"pub type Error {\n  IsGreater(value: Int, expected: Int)\n  IsGreaterOrEqual(value: Int, expected: Int)\n  IsLonger(value: String, actual: Int, expected: Int)\n  IsLesser(value: Int, expected: Int)\n  IsLesserOrEqual(value: Int, expected: Int)\n  IsEqual(value: String, expected: String)\n  IsIncludedIn(value: String, expected: String)\n  IsBool(value: Bool, expected: Bool)\n}\n\nIsGreater(value: Int, expected: Int)\n\n\nIsGreaterOrEqual(value: Int, expected: Int)\n\n\nIsLonger(value: String, actual: Int, expected: Int)\n\n\nIsLesser(value: Int, expected: Int)\n\n\nIsLesserOrEqual(value: Int, expected: Int)\n\n\nIsEqual(value: String, expected: String)\n\n\nIsIncludedIn(value: String, expected: String)\n\n\nIsBool(value: Bool, expected: Bool)\n\n\nSynonyms:\nokay.Error\nokay Error","url":"okay.html#Error"},{"doc":"okay","title":"Okay","content":"pub type Okay {\n  Okay(errors: List(ValidationError))\n}\n\nOkay(errors: List(ValidationError))\n\n\nSynonyms:\nokay.Okay\nokay Okay","url":"okay.html#Okay"},{"doc":"okay","title":"ValidationError","content":"pub type ValidationError {\n  ValidationError(field: String, error: Error)\n}\n\nValidationError(field: String, error: Error)\n\n\nSynonyms:\nokay.ValidationError\nokay ValidationError","url":"okay.html#ValidationError"},{"doc":"okay","title":"field","content":"pub fn field(\n  okay: Okay,\n  field: String,\n  result: Result(Nil, Error),\n) -&gt; Okay\n\nSynonyms:\nokay.field\nokay field","url":"okay.html#field"},{"doc":"okay","title":"is_equal","content":"pub fn is_equal(value: a, compare: a) -&gt; Result(Nil, Error)\n\nSynonyms:\nokay.is_equal\nokay is_equal","url":"okay.html#is_equal"},{"doc":"okay","title":"is_false","content":"pub fn is_false(value: Bool) -&gt; Result(Nil, Error)\n\nSynonyms:\nokay.is_false\nokay is_false","url":"okay.html#is_false"},{"doc":"okay","title":"is_gt","content":"pub fn is_gt(value: Int, compare: Int) -&gt; Result(Nil, Error)\n\nSynonyms:\nokay.is_gt\nokay is_gt","url":"okay.html#is_gt"},{"doc":"okay","title":"is_gte","content":"pub fn is_gte(value: Int, compare: Int) -&gt; Result(Nil, Error)\n\nSynonyms:\nokay.is_gte\nokay is_gte","url":"okay.html#is_gte"},{"doc":"okay","title":"is_included_in","content":"pub fn is_included_in(\n  value: a,\n  whitelist: List(a),\n) -&gt; Result(Nil, Error)\n\nSynonyms:\nokay.is_included_in\nokay is_included_in","url":"okay.html#is_included_in"},{"doc":"okay","title":"is_longer","content":"pub fn is_longer(\n  value: String,\n  length: Int,\n) -&gt; Result(Nil, Error)\n\nSynonyms:\nokay.is_longer\nokay is_longer","url":"okay.html#is_longer"},{"doc":"okay","title":"is_lt","content":"pub fn is_lt(value: Int, compare: Int) -&gt; Result(Nil, Error)\n\nSynonyms:\nokay.is_lt\nokay is_lt","url":"okay.html#is_lt"},{"doc":"okay","title":"is_lte","content":"pub fn is_lte(value: Int, compare: Int) -&gt; Result(Nil, Error)\n\nSynonyms:\nokay.is_lte\nokay is_lte","url":"okay.html#is_lte"},{"doc":"okay","title":"is_true","content":"pub fn is_true(value: Bool) -&gt; Result(Nil, Error)\n\nSynonyms:\nokay.is_true\nokay is_true","url":"okay.html#is_true"},{"doc":"okay","title":"new","content":"pub fn new() -&gt; Okay\n\nSynonyms:\nokay.new\nokay new","url":"okay.html#new"},{"doc":"okay","title":"run","content":"pub fn run(okay: Okay) -&gt; Result(Nil, Okay)\n\nSynonyms:\nokay.run\nokay run","url":"okay.html#run"},{"doc":"okay","title":"okay","content":"","url":"okay.html"}]);